=====================
bodhi-approve-testing
=====================

Synopsis
========

``bodhi-approve-testing`` CONFIG_PATH


Description
===========

``bodhi-approve-testing`` is used to examine the updates in testing to determine if they have met
testing requirements. If they have, a comment will be added from the bodhi user to inform the
packager that the update may now be pushed to stable.

CONFIG_PATH must be the path to the server's configuration ini file.


Help
====

If you find bugs in bodhi (or in the man page), please feel free to file a bug report or a pull
request:

    https://github.com/fedora-infra/bodhi

Bodhi's documentation is available online: https://bodhi.fedoraproject.org/docs
